# plenary

[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.7002489.svg)](https://doi.org/10.5281/zenodo.7002489) ![license](https://img.shields.io/github/license/swinburne-sensing/plenary) ![python version](https://img.shields.io/pypi/pyversions/plenary) ![testing](https://github.com/swinburne-sensing/plenary/actions/workflows/python.yml/badge.svg) ![issues](https://img.shields.io/github/issues/swinburne-sensing/plenary)


A library of convenient utility methods and classes. Designed to work in pure python.

## Acknowledgments

Developed at [Swinburne University of Technology](https://swin.edu.au). If used in an academic project, please consider citing this work as it helps attract funding and track research outputs:

```
C. J. Harrison and M. Shafiei. plenary. (2022). [Online]. doi: https://dx.doi.org/10.5281/zenodo.7002489
```

*This activity received funding from [ARENA](https://arena.gov.au) as part of ARENA’s Research and Development Program – Renewable Hydrogen for Export (Contract No. 2018/RND012). The views expressed herein are not necessarily the views of the Australian Government, and the Australian Government does not accept responsibility for any information or advice contained herein.*

*The work has been supported by the [Future Energy Exports CRC](https://www.fenex.org.au) whose activities are funded by the Australian Government's Cooperative Research Centre Program.*
